Class: Markbridge::Processors::DiscourseMarkdown::Detectors::Base Abstract
- Inherits:
-
Object
- Object
- Markbridge::Processors::DiscourseMarkdown::Detectors::Base
- Defined in:
- lib/markbridge/processors/discourse_markdown/detectors/base.rb
Overview
This class is abstract.
Subclass and implement #detect
Base class for construct detectors. Subclasses implement detection logic for specific constructs (mentions, polls, events, uploads).
Instance Method Summary collapse
-
#detect(input, pos) ⇒ Match?
Attempt to detect a construct at the given position.
Instance Method Details
#detect(input, pos) ⇒ Match?
Attempt to detect a construct at the given position.
24 25 26 |
# File 'lib/markbridge/processors/discourse_markdown/detectors/base.rb', line 24 def detect(input, pos) raise NotImplementedError, "#{self.class} must implement #detect" end |