Class: Markbridge::AST::Node Abstract
- Inherits:
-
Object
- Object
- Markbridge::AST::Node
- Defined in:
- lib/markbridge/ast/node.rb
Overview
This class is abstract.
Subclass and add specific behavior
Base class for all AST nodes. This is a marker class that serves as the common ancestor for all AST nodes.
The AST hierarchy consists of:
All node types inherit from this base class to enable type checking and polymorphic operations on the AST tree.
Direct Known Subclasses
Attachment, Element, Event, HorizontalRule, LineBreak, MarkdownText, Mention, Poll, Text, Upload